#
# spec file for package perl-Devel-StackTrace
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Devel-StackTrace
Name:           perl-Devel-StackTrace
Version:        2.50.0
Release:        2.2
%define cpan_version 2.05
License:        Artistic-2.0
Summary:        An object representing a stack trace
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DR/DROLSKY/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.96
Provides:       perl(Devel::StackTrace) = %{version}
Provides:       perl(Devel::StackTrace::Frame) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
The 'Devel::StackTrace' module contains two classes, 'Devel::StackTrace'
and Devel::StackTrace::Frame. These objects encapsulate the information
that can retrieved via Perl's 'caller' function, as well as providing a
simple interface to this data.

The 'Devel::StackTrace' object contains a set of 'Devel::StackTrace::Frame'
objects, one for each level of the stack. The frames contain all the data
available from 'caller'.

This code was created to support my Exception::Class::Base class (part of
Exception::Class) but may be useful in other contexts.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CODE_OF_CONDUCT.md CONTRIBUTING.md README.md
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Tue Jan  9 2024 Tina Müller <timueller+perl@suse.de>
- updated to 2.05
  see /usr/share/doc/packages/perl-Devel-StackTrace/Changes
  2.05   2024-01-08
  - Added explicit boolean overloading for trace objects. Without this, Perl
    will use the object's string overloading and then check the truthiness of
    the returned string, which is a lot of extra work. This can produce
    significant slowdowns in some cases, as seen in
    https://github.com/plack/Plack/pull/697. Requested by Tatsuhiko
    Miyagawa. GH #23.
* Sat May 25 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.04
  see /usr/share/doc/packages/perl-Devel-StackTrace/Changes
  2.04   2019-05-24
  - Add a partial workaround for "Bizarre copy" errors (GH #11) that come when
    attempting to look at arguments in the call stack. This is only a partial
    fix as there are cases that can lead to a SEGV. Ultimately this needs to be
    fixed in the Perl core. See
    https://rt.perl.org/Public/Bug/Display.html?id=131046 for relevant
    discussion. Fixed by pali. GH #21.
* Sun Nov 19 2017 coolo@suse.com
- updated to 2.03
  see /usr/share/doc/packages/perl-Devel-StackTrace/Changes
  2.03   2017-11-18
  - If all frames in the trace were skipped (via skip_frames, frame_filter,
    ignore_*, etc.), then the stringified stack trace would be an empty
    string. Now this has been changed to always return the message given to the
    constructor or the string "Trace begun". Fixes GH #15, reported by Karen
    Etheridge.
* Thu Dec  8 2016 coolo@suse.com
- updated to 2.02
  see /usr/share/doc/packages/perl-Devel-StackTrace/Changes
  2.02   2016-12-07
  - Switch to GitHub Issues.
  - Some small pod fixes.
* Tue Mar  8 2016 coolo@suse.com
- updated to 2.01
  see /usr/share/doc/packages/perl-Devel-StackTrace/Changes
  2.01   2016-03-02
  - Fixed the frames method when it is called with arguments. Previously this
    did not work if it was called before the method was called as a
    reader. Fixed by Mark Fowler. PR #8.
* Thu Apr 16 2015 coolo@suse.com
- updated to 2.00
  see /usr/share/doc/packages/perl-Devel-StackTrace/Changes
  2.00   2014-11-01
  [BACKWARDS INCOMPATIBILITIES]
  - The no_refs constructor parameter is now deprecated, and has been replace by
    a new unsafe_ref_capture parameter that defaults to false, meaning no
    references are captured by default. Capturing references by default caused
    too many issues that couldn't be worked around, including running DESTROY
    blocks multiple times on captured objects in the worst case.
  - Removed support for the long-deprecated no_object_refs constructor parameter
    (deprecated in 2002!).
* Fri Sep 19 2014 coolo@suse.com
- updated to 1.34
  - Fixed use of // operator (my use, not Graham's) in previous release.
  1.33   2014-06-26
  - Added a skip_frames option. This causes the stack trace to skip an arbitrary
  number of frames. Patch by Graham Knopp. PR #5.
  1.32   2014-05-05
  - Added a filter_frames_early option to filter frames before arguments are
  stringified. Added by Dagfinn Ilmari Mannsåker. PR #4.
* Mon Feb 24 2014 coolo@suse.com
- updated to 1.31
  - No code changes, just doc updates, including documenting the as_string()
  method in Devel::StackTrace::Frame. Requested by Skef. RT #91575.
- remove Devel-StackTrace-1.27_Test_More.patch
* Tue Jun  4 2013 coolo@suse.com
- updated to 1.30
  - There was an eval which did not first localize $@ and $SIG{__DIE__}. This
  broke Plack::Middleware::StackTrace (and possibly other tihngs).
  - The Devel::StackTrace->frames() method is now read-write. This allows you to
  do more complex filtering of frames than is easily possible with the
  frame_filter argument to the constructor. Patch by David Cantrell.
  - Allow arguments to a trace's as_string method, specifically max_arg_length
  Patch by Ricardo Signes.
  - Added a no_args option to the constructor in 1.26 but forgot to mention it
  in Changes. Requested by Scott J. Miller. RT #71482.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Feb  1 2011 chris@computersalat.de
- fix deps
  * created by cpanspec 1.78.03
- fix build for suse_version < 1120
  o add Test_More patch
* Wed Jan 19 2011 coolo@novell.com
- update to version 1.27
  - Skip some tests on 5.13.8+ that are no longer relevant because of a change
    in the Perl core. Reported by Andreas Koenig. RT #64828.
  - The as_string method did not localize $@ and $SIG{__DIE__} before doing an
  eval. Reported and tested by Marc Mims. RT #61072.
  - Moved the frame object to its own file, and renamed it
    Devel::StackTrace::Frame. The old package name, Devel::StackTraceFrame, is
    now a subclass of the new package, to provide a backwards compatibility
    shim.
  - Added message and indent constructor parameters. Based on a patch by James
    Laver. RT #59830.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Mar  8 2010 chris@computersalat.de
- update to version 1.22
  - Apparently, overload::StrVal on older Perls (5.8.5, but not 5.8.8)
    tried to call a stringification method if it existed. So now,
    Devel::StackTrace just uses overload::AddrRef instead, which should
    always be safe. Reported by Michael Stevens. Fixes RT #47900.
- 1.21  Jul 1, 2009
  - Overloaded objects which didn't provide a stringification method
    cause Devel::StackTrace to die when respect_overload was
    true. Reported by Laurent Dami. RT #39533.
  - Added a frame_filter option which allows for fine-grained control
    over what frames are included in a trace. Based on (but expanded)
    from a patch proposed by Florian Ragwitz. RT #47415.
- cleanup spec
  - Header version
  - License
  - Provides
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sat Jun 27 2009 chris@computersalat.de
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o added header
  o fixed deps
* Thu Mar 19 2009 lars@linux-schulserver.de
- update to 1.20:
  + many test fixes
  + bad utf-8 fixes
  + Added a max_arg_length parameter, which if set causes
    Devel::StackTrace to truncate long strings when printing out a
    frame. RT #33519. Patch by Ian Burrell.
* Wed Oct 31 2007 James Oakley <jfunk@funktronics.ca> - 1.15-1
- Initial release
